package cn.com.qmth.examcloud.core.basic.base.util;

import org.apache.commons.lang3.StringUtils;

public class PhotoPathHelper {

    /**
     * 修正学生照片路径（兼容旧数据）
     * 路径规则：/student_base_photo/{rootOrgId}/{userId}/{timeMillis}{fileSuffix}
     *
     * @param photoPath 文件存储路径，格式示例：
     *                  https://ecs-static-upyun.qmth.com.cn/student_base_photo/0/1/1709710625950.png 又拍云路径（旧数据）
     *                  https://ecs-static.qmth.com.cn/student_base_photo/0/1/1709710625950.png
     *                  upyun-1://student_base_photo/0/1/1709710625950.png
     *                  aliyun-1://student_base_photo/0/1/1709710625950.png
     *                  aliyun-2://student_base_photo/0/1/1709710625950.png
     *                  /student_base_photo/0/1/1709710625950.png
     *                  student_base_photo/0/1/1709710625950.png
     *                  /0/1/1709710625950.png 缺少根目录（旧数据）
     *                  0/1/1709710625950.png 缺少根目录（旧数据）
     * @return 标准规则的学生照片路径
     */
    public static String fixPhotoPath(String photoPath) {
        if (StringUtils.isEmpty(photoPath)) {
            return "";
        }

        if (photoPath.toLowerCase().startsWith("http")) {
            return photoPath;
        }

        photoPath = photoPath.replace("upyun-1://", "").replace("aliyun-1://", "").replace("aliyun-2://", "");

        if (photoPath.contains("student_base_photo")) {
            if (photoPath.startsWith("/")) {
                return photoPath;
            }
            return "/" + photoPath;
        } else {
            if (photoPath.startsWith("/")) {
                return "/student_base_photo" + photoPath;
            }
            return "/student_base_photo/" + photoPath;
        }
    }

    /*public static void main(String[] args) {
        System.out.println(fixPhotoPath("0/1/1709710625950.png"));
    }*/

}
